@@ -8,7 +8,8 @@ DF = structure(list(y=3:4, z=c(6,5), x=1:2, A=c("b", "a")),
 ll = list(a=a, A=A, DF=DF)
 
 test_that("vector and dropping rules", {
-    expect_equal(dimnames(a), dimnames(a, drop=FALSE), dn[1])
+    expect_equal(dimnames(a), dimnames(a, drop=FALSE))
+    expect_equal(dimnames(a), dn[1])
     expect_equal(dimnames(a, drop=TRUE), dn[[1]])
     expect_equal(dimnames(a, along=1), dn[[1]])
     expect_equal(dimnames(a, along=1, drop=FALSE), dn[1])
@@ -16,7 +17,7 @@ test_that("vector and dropping rules", {
 
 test_that("ignore along for vector, not array", {
     expect_equal(dimnames(a, along=2), dn[[1]])
-    expect_error(dimnmaes(as.array(a), along=2))
+    expect_error(dimnames(as.array(a), along=2))
 })
 
 test_that("matrix", {
